import { Store as _Store, StoreOptions } from 'vuex';
import { PromiseAction, Mutation, Module, Getters, Actions, State, Mutations, OnlyString, GetNameSpaceKeys, GetNameSpaceObject } from './types';
/**
 * methods override ordering must be
 * mapper > keys
 * root > namespaces
 */
export declare class EnhanceStore<S, T extends StoreOptions<S>> {
    store: _Store<S>;
    constructor(s: T);
    dispatch<Key extends OnlyString<Actions<T>>>(action: Key): PromiseAction<Actions<T>[Key]>;
    dispatch<NameSpace extends OnlyString<Module<T>>, Key extends GetNameSpaceKeys<T, NameSpace, 'actions'>>(namespace: NameSpace, key: Key): PromiseAction<GetNameSpaceObject<T, NameSpace, 'actions'>[Key]>;
    /**
     * mapGetters
     */
    mapGetters<Map extends Record<string, K>, K extends OnlyString<Getters<T>>>(k: Map): {
        [k in keyof Map]: () => ReturnType<Getters<T>[Map[k]]>;
    };
    mapGetters<Keys extends OnlyString<Getters<T>>>(k: Keys[]): {
        [k in Keys]: () => ReturnType<Getters<T>[k]>;
    };
    mapGetters<NameSpace extends OnlyString<Module<T>>, Map extends Record<string, Keys>, Keys extends GetNameSpaceKeys<T, NameSpace, 'getters'>>(k: NameSpace, m: Map): {
        [k in keyof Map]: () => ReturnType<GetNameSpaceObject<T, NameSpace, 'getters'>[Map[k]]>;
    };
    mapGetters<NameSpace extends OnlyString<Module<T>>, Keys extends GetNameSpaceKeys<T, NameSpace, 'getters'>>(k: NameSpace, u: Keys[]): {
        [K in Keys]: () => ReturnType<GetNameSpaceObject<T, NameSpace, 'getters'>[K]>;
    };
    /**
     * mapActions
     */
    mapActions<Map extends Record<string, K>, K extends OnlyString<Actions<T>>>(k: Map): {
        [k in keyof Map]: PromiseAction<Actions<T>[Map[k]]>;
    };
    mapActions<Keys extends OnlyString<Actions<T>>>(k: Keys[]): {
        [k in Keys]: PromiseAction<Actions<T>[k]>;
    };
    mapActions<NameSpace extends OnlyString<Module<T>>, Map extends Record<string, Keys>, Keys extends GetNameSpaceKeys<T, NameSpace, 'actions'>>(k: NameSpace, m: Map): {
        [k in keyof Map]: PromiseAction<GetNameSpaceObject<T, NameSpace, 'actions'>[Map[k]]>;
    };
    mapActions<NameSpace extends OnlyString<Module<T>>, Keys extends GetNameSpaceKeys<T, NameSpace, 'actions'>>(k: NameSpace, u: Keys[]): {
        [K in Keys]: PromiseAction<GetNameSpaceObject<T, NameSpace, 'actions'>[K]>;
    };
    /**
     * mapMutations
     */
    mapMutations<Map extends Record<string, K>, K extends OnlyString<Mutations<T>>>(k: Map): {
        [k in keyof Map]: Mutation<Mutations<T>[Map[k]]>;
    };
    mapMutations<Keys extends OnlyString<Mutations<T>>>(k: Keys[]): {
        [k in Keys]: Mutation<Mutations<T>[k]>;
    };
    mapMutations<NameSpace extends OnlyString<Module<T>>, Map extends Record<string, Keys>, Keys extends GetNameSpaceKeys<T, NameSpace, 'mutations'>>(k: NameSpace, m: Map): {
        [k in keyof Map]: Mutation<GetNameSpaceObject<T, NameSpace, 'mutations'>[Map[k]]>;
    };
    mapMutations<NameSpace extends OnlyString<Module<T>>, Keys extends GetNameSpaceKeys<T, NameSpace, 'mutations'>>(k: NameSpace, u: Keys[]): {
        [K in Keys]: Mutation<GetNameSpaceObject<T, NameSpace, 'mutations'>[K]>;
    };
    /**
     * mapState
     */
    mapState<Map extends Record<string, K>, K extends OnlyString<State<T>>>(k: Map): {
        [k in keyof Map]: () => State<T>[Map[k]];
    };
    mapState<Keys extends OnlyString<State<T>>>(k: Keys[]): {
        [k in Keys]: () => State<T>[k];
    };
    mapState<NameSpace extends OnlyString<Module<T>>, Map extends Record<string, Keys>, Keys extends GetNameSpaceKeys<T, NameSpace, 'state'>>(k: NameSpace, m: Map): {
        [k in keyof Map]: () => GetNameSpaceObject<T, NameSpace, 'state'>[Map[k]];
    };
    mapState<NameSpace extends OnlyString<Module<T>>, Keys extends GetNameSpaceKeys<T, NameSpace, 'state'>>(k: NameSpace, u: Keys[]): {
        [K in Keys]: () => GetNameSpaceObject<T, NameSpace, 'state'>[K];
    };
}
